changeset 71:b6fe4a2411ee

restructure to handle xarg replacement
author smith@nwoca.org
date Fri, 18 Mar 2016 01:32:43 +0100
parents b55117e40cd7
children 6f562946db80
files scripts/capture.sh
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/scripts/capture.sh	Fri Mar 18 01:24:12 2016 +0100
+++ b/scripts/capture.sh	Fri Mar 18 01:32:43 2016 +0100
@@ -1,3 +1,3 @@
 #!/bin/bash
-# writes current logs to standard outfrom running containers in current compose project.
-docker-compose ps -q | xargs -I{}  bash -c "cat $(docker inspect --format='{{.LogPath}}' {} ) "
+# writes tail of current logs to standard out from running containers in compose project.
+docker-compose ps -q | xargs -I ID docker inspect --format='{{.LogPath}}' ID | xargs tail -n1000
\ No newline at end of file